chemo: Response to chemotherapy data

chemoR Documentation

Response to chemotherapy data

Description

This data.frame contains the data from a study on large primary breast cancer, in which the aim was to evaluate the use of PET/CT imagining in predicting response to neoadjuvant chemotherapy. The study recruited 50 patients. The following variables have been collected:

  • id Patient identifier

  • SUV percent change in maximum standardised uptake value (SUV) (%) between the baseline evaluation (before treatment) and the evaluation after two cycles of neoadjuvant chemotherapy, quantified using PET/CT imaging. The following formula was used to calculate this variable:

    \frac{\mbox{SUV}_b-\mbox{SUV}_2}{\mbox{SUV}_b} \cdot 100,

    where \mbox{SUV}_b is the maximum SUV in the baseline evaluation and \mbox{SUV}_2 is the maximum SUV after two cycles

  • resp Response evaluated after the completion of the neoadjuvant chemotherapy, in accordance with the RECIST guidelines: complete response (lesions completely disappeared), partial response (lesions showed at least a 30% decrease in size), stable disease (otherwise)

Usage

data("chemo")

References

Duch J, Fuster D, Munoz M, Fernandez P, Paredes P, Fontanillas M, Guzman F, Rubi S, Lomena F, Pons F. (2009). 18 F-FDG PET/CT for Early Prediction of Response to Neoadjuvant Chemotherapy in Breast Cancer. European Journal of Nuclear Molecular Imaging, 36, 1551-1557.

Skaltsa K, Jover L, Fuster D, Carrasco JL. (2012). Optimum threshold estimation based on cost function in a multistate diagnostic setting. Statistics in Medicine, 31:1098-1109.


ThresholdROC documentation built on July 27, 2026, 9:11 a.m.